@@ -16,15 +16,15 @@
 #define down(x,y) ((x) & ~((y)-1))
 #define square(x) (data[(x)]*data[(x)])
 
-La_extern void F77_NAME(dtrttf)(const char* transr, const char* uplo, const La_INT *n,
-         const double* a, const La_INT *lda,
-         double* arf, La_INT *info FCLEN FCLEN);
+La_extern void F77_NAME(dtrttf)(const char* transr, const char* uplo, const int* n,
+         const double* a, const int* lda,
+         double* arf, int* info FCLEN FCLEN);
 
-La_extern void F77_NAME(dpftrf)(const char* transr, const char* uplo, const La_INT* n,
-         double* a, La_INT* info FCLEN FCLEN);
+La_extern void F77_NAME(dpftrf)(const char* transr, const char* uplo, const int* n,
+         double* a, int* info FCLEN FCLEN);
 
 La_extern void F77_NAME(dtfsm)(const char* transr, const char* side, const char* uplo, const char* trans, const char* diag,
-        const La_INT* m, const La_INT* n, const double* alpha, const double* a,
-        double* b, const La_INT* ldb FCLEN FCLEN FCLEN FCLEN FCLEN);
+        const int* m, const int* n, const double* alpha, const double* a,
+        double* b, const int* ldb FCLEN FCLEN FCLEN FCLEN FCLEN);
 
 
